@@ -60,27 +60,20 @@ extern "C" {
     }
 }
 
-static const char *certid = "generic";
-
 gnutls_priority_t context::priority_cache;
 
-bool secure::fips(const char *progname)
+bool secure::fips(void)
 {
     return false;
 }
 
-bool secure::init(const char *progname)
+bool secure::init(void)
 {
     static bool initialized = false;
 
     if(!initialized) {
         Thread::init();
-        if(progname) {
-            Socket::init(progname);
-            certid = progname;
-        }
-        else
-            Socket::init();
+        Socket::init(progname);
 
 #ifndef _MSWINDOWS_
         gcry_control(GCRYCTL_SET_THREAD_CBS, &gcrypt_threading);
@@ -94,11 +87,8 @@ bool secure::init(const char *progname)
     return true;
 }
 
-secure::server_t secure::server(const char *ca)
+secure::server_t secure::server(const char *certfile, const char *ca)
 {
-    char certfile[256];
-    char keyfile[256];
-
     context *ctx = new context;
 
     if(!ctx)
@@ -111,36 +101,19 @@ secure::server_t secure::server(const char *ca)
     ctx->dh = NULL;
     gnutls_certificate_allocate_credentials(&ctx->xcred);
 
-    snprintf(certfile, sizeof(certfile), "%s/%s.pem", SSL_CERTS, certid);
-    snprintf(keyfile, sizeof(keyfile), "%s/%s.pem", SSL_PRIVATE, certid);
-    gnutls_certificate_set_x509_key_file(ctx->xcred, certfile, keyfile, GNUTLS_X509_FMT_PEM);
+    gnutls_certificate_set_x509_key_file(ctx->xcred, certfile, certfile, GNUTLS_X509_FMT_PEM);
 
     if(!ca)
         return ctx;
 
     if(eq(ca, "*"))
-        ca = SSL_CERTS;
-    else if(*ca != '/') {
-        snprintf(certfile, sizeof(certfile), "%s/%s.pem", SSL_CERTS, ca);
-        ca = certfile;
-    }
+        ca = oscerts();
 
-    gnutls_certificate_set_x509_trust_file (ctx->xcred, certfile, GNUTLS_X509_FMT_PEM);
+    gnutls_certificate_set_x509_trust_file (ctx->xcred, ca, GNUTLS_X509_FMT_PEM);
 
     return ctx;
 }
 
-String secure::path(path_t id)
-{
-    switch(id) {
-    case SYSTEM_CERTIFICATES:
-        return str(SSL_CERTS);
-    case SYSTEM_KEYS:
-        return str(SSL_PRIVATE);
-    }
-    return str("");
-}
-
 #if defined(_MSWINDOWS_)
 static void cexport(HCERTSTORE ca, FILE *fp)
 {
@@ -164,23 +137,39 @@ static void cexport(HCERTSTORE ca, FILE *fp)
     }
 }
 
+const char *secure::oscerts(void)
+{
+    const char *path = "c:/temp/ca-bundle.crt";
+    if(!is_file(path)) {
+        if(oscerts(path))
+            return NULL;
+    }
+    return path;
+}
+
 int secure::oscerts(const char *pathname)
 {
     bool caset;
-    string_t target = shell::path(shell::USER_CONFIG) + pathname;
+    string_t target;
+
+    if(pathname[1] == ':' || pathname[0] == '/' || pathname[0] == '\\')
+        target = pathname;
+    else
+        target = shell::path(shell::USER_CONFIG) + "/" + pathname;
+
     FILE *fp = fopen(*target, "wt");
 
     if(!fp)
         return ENOSYS;
 
-    HCERTSTORE ca = CertOpenSystemStoreA(NULL, "ROOT");
+    HCERTSTORE ca = CertOpenSystemStoreA((HCRYPTPROV)NULL, "ROOT");
     if(ca) {
         caset = true;
         cexport(ca, fp);
         CertCloseStore(ca, 0);
     }
 
-    ca = CertOpenSystemStoreA(NULL, "CA");
+    ca = CertOpenSystemStoreA((HCRYPTPROV)NULL, "CA");
     if(ca) {
         caset = true;
         cexport(ca, fp);
@@ -190,19 +179,38 @@ int secure::oscerts(const char *pathname)
     fclose(fp);
 
     if(!caset) {
-        fsys::remove(*target);
+        fsys::erase(*target);
         return ENOSYS;
     }
     return 0;
 }
 
 #else
+const char *secure::oscerts(void)
+{
+    if(is_file("/etc/ssl/certs/ca-certificates.crt"))
+        return "/etc/ssl/certs/ca-certificates.crt";
+
+    if(is_file("/etc/pki/tls/ca-bundle.crt"))
+        return "/etc/pki/tls/ca-bundle.crt";
+
+    if(is_file("/etc/ssl/ca-bundle.pem"))
+        return "/etc/ssl/ca-bundle.pem";
+
+    return NULL;
+}
+
 int secure::oscerts(const char *pathname)
 {
-    string_t source = path(SYSTEM_CERTIFICATES) + "/ca-certificates.crt";
-    string_t target = shell::path(shell::USER_CONFIG) + pathname;
+    string_t source = oscerts();
+    string_t target;
 
-    if(!*source || !*target)
+    if(pathname[0] == '/')
+        target = pathname;
+    else
+        target = shell::path(shell::USER_CONFIG) + "/" + pathname;
+
+    if(!source)
         return ENOSYS;
 
     return fsys::copy(*source, *target);
@@ -211,8 +219,6 @@ int secure::oscerts(const char *pathname)
 
 secure::client_t secure::client(const char *ca)
 {
-    char certfile[256];
-
     context *ctx = new context;
 
     if(!ctx)
@@ -229,13 +235,9 @@ secure::client_t secure::client(const char *ca)
         return ctx;
 
     if(eq(ca, "*"))
-        ca = SSL_CERTS;
-    else if(*ca != '/') {
-        snprintf(certfile, sizeof(certfile), "%s/%s.pem", SSL_CERTS, ca);
-        ca = certfile;
-    }
+        ca = oscerts();
 
-    gnutls_certificate_set_x509_trust_file (ctx->xcred, certfile, GNUTLS_X509_FMT_PEM);
+    gnutls_certificate_set_x509_trust_file (ctx->xcred, ca, GNUTLS_X509_FMT_PEM);
 
     return ctx;
 }
