@@ -16,12 +16,12 @@
 // along with GNU uCommon C++.  If not, see <http://www.gnu.org/licenses/>.
 
 /**
- * Locking classes for member function automatic operations.
+ * Locking protocol classes for member function automatic operations.
  * This header covers ucommon access related classes.  These are used to
  * provide automatic management of locks and synchronization objects through
  * common virtual base classes which can be used with automatic objects.
- * These classes are intended to be used much like "protocols" in conjunction
- * with smart pointer/referencing classes.  This protocol interface supports
+ * These classes are related to "protocols" and are used in conjunction
+ * with smart pointer/referencing classes.  The access interface supports
  * member functions to acquire a lock when entered and automatically
  * release the lock when the member function returns that are used in
  * conjunction with special referencing smart pointers.
@@ -39,35 +39,24 @@
 #include <ucommon/cpr.h>
 #endif
 
+#ifndef _UCOMMON_PROTOCOLS_H_
+#include <ucommon/protocols.h>
+#endif
+
 NAMESPACE_UCOMMON
 
 /**
- * An exclusive locking protocol interface base.
- * This is an abstract class to form objects that will operate under an
- * exclusive lock while being actively referenced by a smart pointer.
+ * Common unlock protocol for locking protocol interface classes.
+ * This is to assure _unlock is a common base virtual method.
  * @author David Sugar <dyfet@gnutelephony.org>
  */
-class __EXPORT ExclusiveProtocol
+class __EXPORT UnlockAccess
 {
-protected:
-    virtual ~ExclusiveProtocol();
-
 public:
-    /**
-     * Protocol interface to exclusive lock the object.
-     */
-    virtual void Exlock(void) = 0;
+    virtual ~UnlockAccess();
 
-    /**
-     * Protocol interface to release a lock.
-     */
-    virtual void Unlock(void) = 0;
-
-    /**
-     * A convenience member function for accessing the exclusive lock.
-     */
-    inline void Lock(void)
-        {Exlock();};
+protected:
+    virtual void _unlock(void) = 0;
 };
 
 /**
@@ -76,29 +65,52 @@ public:
  * exclusive lock while being actively referenced by a smart pointer.
  * @author David Sugar <dyfet@gnutelephony.org>
  */
-class __EXPORT SharedProtocol
+class __EXPORT ExclusiveAccess : public UnlockAccess
 {
 protected:
-    virtual ~SharedProtocol();
+    virtual ~ExclusiveAccess();
+
+    virtual void _lock(void) = 0;
 
 public:
     /**
-     * Protocol interface to share lock the object.
+     * Access interface to exclusive lock the object.
      */
-    virtual void Shlock(void) = 0;
+    inline void exclusive_lock(void)
+        {return _lock();}
 
     /**
-     * Protocol interface to release a lock.
+     * Access interface to release a lock.
      */
-    virtual void Unlock(void) = 0;
+    inline void release_exclusive(void)
+        {return _unlock();}
+};
 
+/**
+ * An exclusive locking access interface base.
+ * This is an abstract class to form objects that will operate under an
+ * exclusive lock while being actively referenced by a smart pointer.
+ * @author David Sugar <dyfet@gnutelephony.org>
+ */
+class __EXPORT SharedAccess : protected UnlockAccess
+{
+protected:
+    virtual ~SharedAccess();
+
+protected:
+    /**
+     * Access interface to share lock the object.
+     */
+    virtual void _share(void) = 0;
+
+public:
     /**
      * Share the lock with other referencers.  Many of our shared locking
      * objects support the ability to switch between shared and exclusive
      * mode.  This derived protocol member allows one to restore the lock
      * to shared mode after it has been made exclusive.
      */
-    virtual void Share(void);
+    virtual void share(void);
 
     /**
      * Convert object to an exclusive lock.  Many of our shared locking
@@ -107,13 +119,13 @@ public:
      * member allows one to temporarily assert exclusive locking when tied
      * to such methods.
      */
-    virtual void Exclusive(void);
+    virtual void exclusive(void);
 
-    /**
-     * A convenience member function for accessing the shared lock.
-     */
-    inline void Lock(void)
-        {Shlock();};
+    inline void shared_lock(void)
+        {return _share();}
+
+    inline void release_share(void)
+        {return _unlock();}
 };
 
 /**
@@ -123,22 +135,22 @@ public:
  * You would pass the pointer an object that has the Exclusive as a base class.
  * @author David Sugar <dyfet@gnutelephony.org>
  */
-class __EXPORT exclusive_lock
+class __EXPORT exclusive_access
 {
 private:
-    ExclusiveProtocol *lock;
+    ExclusiveAccess *lock;
 
 public:
     /**
      * Create an instance of an exclusive object reference.
      * @param object containing Exclusive base class protocol to lock.
      */
-    exclusive_lock(ExclusiveProtocol *object);
+    exclusive_access(ExclusiveAccess *object);
 
     /**
      * Destroy reference to exclusively locked object, release lock.
      */
-    ~exclusive_lock();
+    ~exclusive_access();
 
     /**
      * Test if the reference holds an active lock.
@@ -169,10 +181,10 @@ public:
  * You would pass the pointer an object that has the Shared as a base class.
  * @author David Sugar <dyfet@gnutelephony.org>
  */
-class __EXPORT shared_lock
+class __EXPORT shared_access
 {
 private:
-    SharedProtocol *lock;
+    SharedAccess *lock;
     int state;
     bool modify;
 
@@ -181,12 +193,12 @@ public:
      * Create an instance of an exclusive object reference.
      * @param object containing Exclusive base class protocol to lock.
      */
-    shared_lock(SharedProtocol *object);
+    shared_access(SharedAccess *object);
 
     /**
      * Destroy reference to shared locked object, release lock.
      */
-    ~shared_lock();
+    ~shared_access();
 
     /**
      * Test if the reference holds an active lock.
@@ -224,53 +236,53 @@ public:
  * Convenience function to exclusively lock an object through it's protocol.
  * @param object to lock.
  */
-inline void lock(ExclusiveProtocol *object)
-    {object->Exlock();}
+inline void lock(ExclusiveAccess& object)
+    {object.exclusive_lock();}
 
 /**
  * Convenience function to unlock an exclusive object through it's protocol.
  * @param object to unlock.
  */
-inline void unlock(ExclusiveProtocol *object)
-    {object->Unlock();}
+inline void unlock(ExclusiveAccess& object)
+    {object.release_exclusive();}
 
 /**
  * Convenience function to access (lock) shared object through it's protocol.
  * @param object to share lock.
  */
-inline void access(SharedProtocol *object)
-    {object->Shlock();}
+inline void access(SharedAccess& object)
+    {object.shared_lock();}
 
 /**
  * Convenience function to unlock shared object through it's protocol.
  * @param object to unlock.
  */
-inline void release(SharedProtocol *object)
-    {object->Unlock();}
+inline void release(SharedAccess& object)
+    {object.release_share();}
 
 /**
  * Convenience function to exclusive lock shared object through it's protocol.
  * @param object to exclusive lock.
  */
-inline void exclusive(SharedProtocol *object)
-    {object->Exclusive();}
+inline void exclusive(SharedAccess& object)
+    {object.exclusive();}
 
 /**
  * Convenience function to restore shared locking for object through it's protocol.
  * @param object to restore shared locking.
  */
-inline void share(SharedProtocol *object)
-    {object->Share();}
+inline void share(SharedAccess& object)
+    {object.share();}
 
 /**
  * Convenience type to use for object referencing an exclusive object.
  */
-typedef exclusive_lock exlock_t;
+typedef exclusive_access exlock_t;
 
 /**
  * Convenience type to use for object referencing a shared object.
  */
-typedef shared_lock shlock_t;
+typedef shared_access shlock_t;
 
 /**
  * Convenience function to release a reference to an exclusive lock.
@@ -293,8 +305,8 @@ inline void release(shlock_t &reference)
 
 #define exclusive_object()  exlock_t __autolock__ = this
 #define protected_object()  shlock_t __autolock__ = this
-#define exclusive_access(x) exlock_t __autolock__ = &x
-#define protected_access(x) shlock_t __autolock__ = &x
+#define exclusive_locking(x) exlock_t __autolock__ = &x
+#define protected_locking(x) shlock_t __autolock__ = &x
 
 END_NAMESPACE
 
