@@ -67,12 +67,6 @@ public:
      */
     typedef enum {OK=0, INVALID, MISSING_CERTIFICATE, MISSING_PRIVATEKEY, INVALID_CERTIFICATE, INVALID_AUTHORITY, INVALID_PEERNAME, INVALID_CIPHER} error_t;
 
-    /**
-     * Path types to retrieve.
-     */
-    typedef enum {
-        SYSTEM_CERTIFICATES, SYSTEM_KEYS} path_t;
-
 protected:
     /**
      * Last error flagged for this context.
@@ -107,29 +101,18 @@ public:
 
     /**
      * Initialize secure stack for first use, and report if SSL support is
-     * compiled in.  This allows a program name to be passed, which may be
-     * used for some proxy systems.
-     * @param program name we are initializing for.
+     * compiled in.
      * @return true if ssl support is available, false if not.
      */
-    static bool init(const char *program = NULL);
+    static bool init(void);
 
     /**
      * Initialize secure stack with fips support.  If fips support is not
      * successfully enabled, the secure stack is also not initialized.  Hence
      * init() can be used for non-fips certified operation if fips fails.
-     * @param program name we are initializing for.
      * @return true if fips support enabled and stack initialized.
      */
-    static bool fips(const char *program = NULL);
-
-    /**
-     * Get a certificate path.  This is used to get directories for application
-     * specific certificate stores.
-     * @param id of path to return.
-     * @return path string or emptry string if not supported.
-     */
-    static String path(path_t id);
+    static bool fips(void);
 
     /**
      * Copy system certificates to a local path.
@@ -138,6 +121,12 @@ public:
      */
     static int oscerts(const char *path);
 
+    /**
+     * Get path to system certificates.
+     * @return path to system certificates.
+     */
+    static const char *oscerts(void);
+
     /**
      * Verify a certificate chain through your certificate authority.
      * This uses the ca loaded as an optional argument for client and
@@ -158,7 +147,7 @@ public:
      * @param authority path to use or NULL if none.
      * @return a security context that is cast from derived library.
      */
-    static server_t server(const char *authority = NULL);
+    static server_t server(const char *keyfile = NULL, const char *authority = NULL);
 
     /**
      * Create an anonymous client context with an optional authority to
@@ -187,7 +176,7 @@ public:
      * Determine if the current security context is valid.
      * @return true if valid, -1 if not.
      */
-    inline bool is(void)
+    inline bool is_valid(void) const
         {return error == OK;};
 
     /**
@@ -208,6 +197,13 @@ public:
     template <typename T>
     inline static void erase(T *object)
         {memset(object, 0, sizeof(object)); delete object;}
+
+    inline operator bool()
+        {return is_valid();}
+
+    inline bool operator!()
+        {return !is_valid();}
+
 };
 
 /**
@@ -423,7 +419,7 @@ public:
      * @param name of cipher to check.
      * @return true if supported, false if not.
      */
-    static bool is(const char *name);
+    static bool has(const char *name);
 };
 
 /**
@@ -511,7 +507,7 @@ public:
      * @param name of digest we want to check.
      * @return true if supported, false if not.
      */
-    static bool is(const char *name);
+    static bool has(const char *name);
 
     static void uuid(char *string, const char *name, const unsigned char *ns = NULL);
 
