@@ -158,10 +158,15 @@ NAMESPACE_UCOMMON
 class __EXPORT cidr : public LinkedObject
 {
 protected:
-    int family;
-    inethostaddr_t netmask, network;
-    char name[16];
-    unsigned getMask(const char *cp) const;
+    int Family;
+    inethostaddr_t Netmask, Network;
+    char Name[16];
+
+    unsigned mask(const char *cp) const;
+
+    inethostaddr_t broadcast(void) const;
+
+    unsigned mask(void) const;
 
 public:
     /**
@@ -209,7 +214,7 @@ public:
      * @param address to search for.
      * @return smallest cidr or NULL if none match.
      */
-    static cidr *find(policy *policy, const struct sockaddr *address);
+    static const cidr *find(const policy *policy, const struct sockaddr *address);
 
     /**
      * Get the largest container cidr entry in a list that matches the
@@ -218,7 +223,7 @@ public:
      * @param address to search for.
      * @return largest cidr or NULL if none match.
      */
-    static cidr *container(policy *policy, const struct sockaddr *address);
+    static const cidr *container(const policy *policy, const struct sockaddr *address);
 
     /**
      * Get the saved name of our cidr.  This is typically used with find
@@ -228,40 +233,42 @@ public:
      * @return name of cidr.
      */
     inline const char *getName(void) const
-        {return name;};
+        {return Name;};
 
     /**
      * Get the address family of our cidr block object.
      * @return family of our cidr.
      */
     inline int getFamily(void) const
-        {return family;};
+        {return Family;};
 
     /**
      * Get the network host base address of our cidr block.
      * @return binary network host address.
      */
     inline inethostaddr_t getNetwork(void) const
-        {return network;};
+        {return Network;};
 
     /**
      * Get the effective network mask for our cidr block.
      * @return binary network mask for our cidr.
      */
     inline inethostaddr_t getNetmask(void) const
-        {return netmask;};
+        {return Netmask;};
 
     /**
      * Get the broadcast host address represented by our cidr.
      * @return binary broadcast host address.
      */
-    inethostaddr_t getBroadcast(void) const;
+    inline inethostaddr_t getBroadcast(void) const
+        {return broadcast();}
 
     /**
      * Get the number of bits in the cidr bitmask.
      * @return bit mask of cidr.
      */
-    unsigned getMask(void) const;
+    inline unsigned getMask(void) const
+        {return mask();}
 
     /**
      * Set our cidr to a string address.  Replaces prior value.
@@ -274,7 +281,7 @@ public:
      * @param address of socket to test.
      * @return true if address is within cidr.
      */
-    bool isMember(const struct sockaddr *address) const;
+    bool is_member(const struct sockaddr *address) const;
 
     /**
      * Test if a given socket address falls within this cidr.
@@ -282,7 +289,7 @@ public:
      * @return true if address is within cidr.
      */
     inline bool operator==(const struct sockaddr *address) const
-        {return isMember(address);};
+        {return is_member(address);};
 
     /**
      * Test if a given socket address falls outside this cidr.
@@ -290,7 +297,7 @@ public:
      * @return true if address is outside cidr.
      */
     inline bool operator!=(const struct sockaddr *address) const
-        {return !isMember(address);};
+        {return !is_member(address);};
 };
 
 /**
@@ -316,7 +323,7 @@ public:
      * @param type of service to get.
      * @param protocol of service to get.
      */
-    static struct addrinfo *getaddress(const char *host, const char *service, int type = SOCK_STREAM, int protocol = 0);
+    static struct addrinfo *query(const char *host, const char *service, int type = SOCK_STREAM, int protocol = 0);
 
     /**
      * Release an address list directly.  This is used internally by some
@@ -325,15 +332,6 @@ public:
      */
     static void release(struct addrinfo *list);
 
-    /**
-     * External definition of fd_set type.  This is used to generate
-     * select calls which may be wrapped through an internal function
-     * such as socks proxy or pth library.
-     */
-    typedef void *set_t;
-
-    static const size_t masksize;
-
     /**
      * A generic socket address class.  This class uses the addrinfo list
      * to store socket multiple addresses in a protocol and family
@@ -411,7 +409,20 @@ public:
          * Get the first socket address in our address list.
          * @return first socket address or NULL if none.
          */
-        struct sockaddr *getAddr(void) const;
+        struct sockaddr *get(void) const;
+
+        inline struct sockaddr *getAddr(void) const
+            {return get();}
+
+        inline struct sockaddr *operator()(void) const
+            {return get();}
+
+        /**
+         * Get the first socket address by casted reference.
+         * @return first socket address we resolved or NULL if none.
+         */
+        inline operator struct sockaddr *() const
+            {return get();};
 
         /**
          * Get the first socket address of specified family from our list.
@@ -420,17 +431,28 @@ public:
          */
         struct sockaddr *get(int family) const;
 
+        inline struct sockaddr *operator()(int family) const
+            {return get(family);}
+
+        inline operator struct sockaddr_in *() const
+            {return (struct sockaddr_in *)get(AF_INET);}
+
+#ifdef  AF_INET6
+        inline operator struct sockaddr_in6 *() const
+            {return (struct sockaddr_in6 *)get(AF_INET6);}
+#endif
+
         /**
          * Get the family of the first member in a list of services.
          * @return family of first socket address or 0 if none.
          */
-        int getfamily(void) const;
+        int family(void) const;
 
         /**
          * Find a specific socket address in our address list.
          * @return matching address from list or NULL if not found.
          */
-        struct sockaddr *find(struct sockaddr *addr) const;
+        struct sockaddr *find(const struct sockaddr *addr) const;
 
         /**
          * Get the full socket address list from the object.
@@ -467,12 +489,6 @@ public:
         inline bool operator!() const
             {return list == NULL;};
 
-        /**
-         * Get the first socket address by casted reference.
-         * @return first socket address we resolved or NULL if none.
-         */
-        inline operator struct sockaddr *() const
-            {return getAddr();};
 
         /**
          * Clear current object.
@@ -660,13 +676,13 @@ public:
      * @param value to test for.
      * @return true if at least that many bytes waiting in receive queue.
      */
-    bool isPending(unsigned value) const;
+    bool is_pending(unsigned value) const;
 
     /**
      * Test if socket is connected.
      * @return true if connected.
      */
-    bool isConnected(void) const;
+    bool connected(void) const;
 
     /**
      * Test for pending input data.  This function can wait up to a specified
@@ -674,7 +690,7 @@ public:
      * @param timeout or 0 if none.
      * @return true if input data waiting.
      */
-    bool waitPending(timeout_t timeout = 0) const;
+    bool wait(timeout_t timeout = 0) const;
 
     /**
      * Set nodelay option for tcp socket.
@@ -704,7 +720,7 @@ public:
      * Get the number of bytes of data in the socket receive buffer.
      * @return bytes pending.
      */
-    inline unsigned getPending(void) const
+    inline unsigned pending(void) const
         {return pending(so);};
 
     /**
@@ -792,7 +808,7 @@ public:
      * @param socket descriptor.
      * @return socket type.
      */
-    static int gettype(socket_t socket);
+    static int type(socket_t socket);
 
     /**
      * Set segment size and get MTU.
@@ -808,14 +824,14 @@ public:
      * @param ccid value to set.
      * @return true if success, false if not dccp or not supported ccid used.
      */
-    static bool setccid(socket_t socket, uint8_t ccid);
+    static bool ccid(socket_t socket, uint8_t id);
 
     /**
      * Get the type of a socket.
      * @return socket type.
      */
-    inline int gettype(void)
-        {return gettype(so);};
+    inline int type(void)
+        {return type(so);};
 
     /**
      * Set segment size and get mtu of a socket.
@@ -830,8 +846,8 @@ public:
      * @param ccid to set.
      * @return true if success, false if not dccp or not supported ccid used.
      */
-    inline bool setccid(uint8_t ccid)
-        {return setccid(so, ccid);};
+    inline bool ccid(uint8_t id)
+        {return ccid(so, id);};
 
     /**
      * Set the type of service field of outgoing packets.  Some useful
@@ -881,14 +897,14 @@ public:
      * @param list of groups to join.
      * @return 0 on success, -1 on error.
      */
-    int join(struct addrinfo *list);
+    int join(const struct addrinfo *list);
 
     /**
      * Drop socket from multicast group.
      * @param list of groups to drop.
      * @return 0 on success, -1 on error.
      */
-    int drop(struct addrinfo *list);
+    int drop(const struct addrinfo *list);
 
     /**
      * Socket i/o timer setting.
@@ -921,7 +937,7 @@ public:
      * @param address of peer to send data to if not connected.
      * @return number of bytes actually sent, 0 if none, -1 if error.
      */
-    size_t writeto(const void *data, size_t number, struct sockaddr *address = NULL);
+    size_t writeto(const void *data, size_t number, const struct sockaddr *address = NULL);
 
     /**
      * Read a newline of text data from the socket and save in NULL terminated
@@ -955,7 +971,7 @@ public:
      * @param buffer to save input line.
      * @return number of bytes read, 0 if none, err() has error.
      */
-    size_t readline(string& buffer);
+    size_t readline(String& buffer);
 
     /**
      * Read a newline of text data from the socket and save in NULL terminated
@@ -1075,7 +1091,7 @@ public:
      * @param list of groups to drop.
      * @return 0 on success, -1 on error.
      */
-    static int drop(socket_t socket, struct addrinfo *list);
+    static int drop(socket_t socket, const struct addrinfo *list);
 
     /**
      * Join socket descriptor to multicast group.
@@ -1083,7 +1099,7 @@ public:
      * @param list of groups to join.
      * @return 0 on success, -1 on error.
      */
-    static int join(socket_t socket, struct addrinfo *list);
+    static int join(socket_t socket, const struct addrinfo *list);
 
     /**
      * Get socket error code of socket descriptor.
@@ -1167,22 +1183,22 @@ public:
      * Get the address family of the socket descriptor.
      * @return address family.
      */
-    static int getfamily(socket_t socket);
+    static int family(socket_t socket);
 
     /**
      * Get the address family of a socket address object.
      * @param address to examine.
      * @return address family.
      */
-    inline static int getfamily(struct sockaddr_storage& address)
-        {return ((struct sockaddr *)&address)->sa_family;};
+    inline static int family(const struct sockaddr_storage& address)
+        {return ((const struct sockaddr *)&address)->sa_family;};
 
     /**
      * Get the address family of an internet socket address object.
      * @param address to examine.
      * @return address family.
      */
-    inline static int getfamily(struct sockaddr_internet& address)
+    inline static int family(const struct sockaddr_internet& address)
         {return address.address.sa_family;};
 
     /**
@@ -1205,7 +1221,7 @@ public:
      * @param address of destination, NULL if connected.
      * @return number of bytes sent, -1 if error.
      */
-    static ssize_t sendto(socket_t socket, const void *buffer, size_t size, int flags = 0, struct sockaddr *address = NULL);
+    static ssize_t sendto(socket_t socket, const void *buffer, size_t size, int flags = 0, const struct sockaddr *address = NULL);
 
     /**
      * Send reply on socket.  Used to reply to a recvfrom message.
@@ -1216,8 +1232,8 @@ public:
      * @param address to reply to.
      * @return number of bytes sent, -1 if error.
      */
-    inline static ssize_t replyto(socket_t socket, const void *buffer, size_t size, int flags, struct sockaddr_storage *address)
-        {return sendto(socket, buffer, size, flags, (struct sockaddr *)address);};
+    inline static ssize_t replyto(socket_t socket, const void *buffer, size_t size, int flags, const struct sockaddr_storage *address)
+        {return sendto(socket, buffer, size, flags, (const struct sockaddr *)address);};
 
     /**
      * Send to internet socket.
@@ -1228,8 +1244,8 @@ public:
      * @param address to send to.
      * @return number of bytes sent, -1 if error.
      */
-    inline static ssize_t sendinet(socket_t socket, const void *buffer, size_t size, int flags, struct sockaddr_internet *address)
-        {return sendto(socket, buffer, size, flags, (struct sockaddr *)address);};
+    inline static ssize_t sendinet(socket_t socket, const void *buffer, size_t size, int flags, const struct sockaddr_internet *address)
+        {return sendto(socket, buffer, size, flags, (const struct sockaddr *)address);};
 
     /**
      * Get internet data waiting in receive queue.
@@ -1259,7 +1275,7 @@ public:
      * @param backlog for service.
      * @return 0 on success, -1 if error.
      */
-    static int listento(socket_t socket, struct sockaddr *address, int backlog = 5);
+    static int listento(socket_t socket, const struct sockaddr *address, int backlog = 5);
 
     /**
      * Bind the socket descriptor to a known interface.
@@ -1267,7 +1283,7 @@ public:
      * @param address of interface to bind to.
      * @return 0 on success, -1 if error.
      */
-    static int bindto(socket_t socket, struct sockaddr *address);
+    static int bindto(socket_t socket, const struct sockaddr *address);
 
     /**
      * Accept a socket connection from a remote host.
@@ -1293,7 +1309,7 @@ public:
      * @param protocol of socket.
      * @return socket descriptor created or INVALID_SOCKET.
      */
-    static socket_t create(struct addrinfo *address, int type, int protocol);
+    static socket_t create(const struct addrinfo *address, int type, int protocol);
 
     /**
      * Create a bound socket for a service.
@@ -1311,7 +1327,7 @@ public:
      * @param address of service for connect.
      * @return socket descriptor.
      */
-    static socket_t create(Socket::address &address);
+    static socket_t create(const Socket::address &address);
 
     /**
      * Release (close) a socket.
@@ -1319,52 +1335,6 @@ public:
      */
     static void release(socket_t socket);
 
-    /**
-     * Send to socket object.
-     * @param socket object to send thru.
-     * @param buffer to send.
-     * @param size of buffer to send.
-     * @param address to send to or NULL if connected.
-     * @return number of bytes send, -1 if error.
-     */
-    inline static size_t writeto(Socket& socket, const char *buffer, size_t size, struct sockaddr *address)
-        {return socket.writeto(buffer, size, address);};
-
-    /**
-     * receive from socket object.
-     * @param socket object to recv from.
-     * @param buffer to recv.
-     * @param size of buffer to recv.
-     * @param address receiving from or NULL if connected.
-     * @return number of bytes received, -1 if error.
-     */
-    inline static size_t readfrom(Socket& socket, char *buffer, size_t size, struct sockaddr_storage *address)
-        {return socket.readfrom(buffer, size, address);};
-
-    /**
-     * Connect a socket.
-     * @param socket object to connect.
-     * @param address list to connect to.
-     */
-    inline static void connectto(Socket& socket, Socket::address &address)
-        {socket.connectto(address);};
-
-    /**
-     * Disconnect a connected socket.
-     * @param socket object to disconnect.
-     */
-    inline static void disconnect(Socket& socket)
-        {socket.disconnect();};
-
-    /**
-     * Accept connection through socket.
-     * @param socket object to accept from.
-     * @param address accepting from.
-     * @return socket accepted.
-     */
-    inline static Socket acceptfrom(Socket& socket, struct sockaddr_storage *address)
-        {return Socket(acceptfrom(socket.so, address));};
-
     /**
      * Lookup and return the host name associated with a socket address.
      * @param address to lookup.
@@ -1372,7 +1342,7 @@ public:
      * @param size of buffer to save hostname into.
      * @return buffer or NULL if lookup fails.
      */
-    static char *gethostname(struct sockaddr *address, char *buffer, size_t size);
+    static char *hostname(const struct sockaddr *address, char *buffer, size_t size);
 
     /**
      * Create an address info lookup hint based on the family and type
@@ -1381,7 +1351,7 @@ public:
      * @param hint buffer.
      * @return hint buffer.
      */
-    static struct addrinfo *gethint(socket_t socket, struct addrinfo *hint);
+    static struct addrinfo *hinting(socket_t socket, struct addrinfo *hint);
 
     /**
      * Lookup a host name and service address based on the addressing family
@@ -1393,14 +1363,14 @@ public:
      * @param service port.
      * @return socket address size.
      */
-    static socklen_t getaddr(socket_t socket, struct sockaddr_storage *address, const char *hostname, const char *service);
+    static socklen_t query(socket_t socket, struct sockaddr_storage *address, const char *hostname, const char *service);
 
     /**
      * Get the size of a socket address.
      * @param address of socket.
      * @return size to use for this socket address object.
      */
-    static socklen_t getlen(struct sockaddr *address);
+    static socklen_t len(const struct sockaddr *address);
 
     /**
      * Compare socket addresses.  Test if the address and service matches
@@ -1409,7 +1379,7 @@ public:
      * @param address2 to compare.
      * @return true if same family and equal.
      */
-    static bool equal(struct sockaddr *address1, struct sockaddr *address2);
+    static bool equal(const struct sockaddr *address1, const struct sockaddr *address2);
 
     /**
      * Copy a socket address.
@@ -1417,7 +1387,7 @@ public:
      * @param origin address pointer to copy from.
      * @return number of bytes copied, 0 if invalid.
      */
-    static unsigned copy(struct sockaddr *target, struct sockaddr *origin);
+    static unsigned copy(struct sockaddr *target, const struct sockaddr *origin);
 
     /**
      * Store an address into an address object.
@@ -1425,7 +1395,7 @@ public:
      * @param address to store.
      * @return number of bytes stored.
      */
-    inline static unsigned store(struct sockaddr_storage *storage, struct sockaddr *address)
+    inline static unsigned store(struct sockaddr_storage *storage, const struct sockaddr *address)
         {return copy((struct sockaddr*)storage, address);};
 
     /**
@@ -1434,7 +1404,7 @@ public:
      * @param address to store.
      * @return number of bytes stored.
      */
-    static unsigned store(struct sockaddr_internet *storage, struct sockaddr *address);
+    static unsigned store(struct sockaddr_internet *storage, const struct sockaddr *address);
 
     /**
      * Compare socket host addresses.  Test if the host address matches
@@ -1443,7 +1413,7 @@ public:
      * @param address2 to compare.
      * @return true if same family and equal.
      */
-    static bool equalhost(struct sockaddr *address1, struct sockaddr *address2);
+    static bool eq_host(const struct sockaddr *address1, const struct sockaddr *address2);
 
     /**
      * Compare socket addresses.  Test if the stored addresses received match.
@@ -1452,8 +1422,8 @@ public:
      * @param address2 to compare.
      * @return true if same family and equal.
      */
-    inline static bool equalfrom(struct sockaddr_storage *address1, struct sockaddr_storage *address2)
-        {return equal((struct sockaddr *)address1, (struct sockaddr *)address2);};
+    inline static bool eq_from(const struct sockaddr_storage *address1, const struct sockaddr_storage *address2)
+        {return equal((const struct sockaddr *)address1, (const struct sockaddr *)address2);};
 
     /**
      * Compare socket addresses.  Test if the internet addresses received match.
@@ -1462,8 +1432,8 @@ public:
      * @param address2 to compare.
      * @return true if same family and equal.
      */
-    inline static bool equalinet(struct sockaddr_internet *address1, struct sockaddr_internet *address2)
-        {return equal((struct sockaddr *)address1, (struct sockaddr *)address2);};
+    inline static bool eq_inet(const struct sockaddr_internet *address1, const struct sockaddr_internet *address2)
+        {return equal((const struct sockaddr *)address1, (const struct sockaddr *)address2);};
 
     /**
      * See if both addresses are in the same subnet.  This is only relevant
@@ -1472,7 +1442,7 @@ public:
      * @param address2 to test.
      * @return true if in same subnet.
      */
-    static bool subnet(struct sockaddr *address1, struct sockaddr *address2);
+    static bool eq_subnet(const struct sockaddr *address1, const struct sockaddr *address2);
 
     /**
      * Get the socket address of the interface needed to reach a destination
@@ -1481,7 +1451,7 @@ public:
      * @param destination address.
      * @return 0 on success, -1 on error.
      */
-    static int getinterface(struct sockaddr *address, struct sockaddr *destination);
+    static int via(struct sockaddr *address, const struct sockaddr *destination);
 
     /**
      * Get the hostname of a socket address.
@@ -1490,22 +1460,22 @@ public:
      * @param size of hostname buffer.
      * @return buffer if found or NULL if not.
      */
-    static char *getaddress(struct sockaddr *address, char *buffer, socklen_t size);
+    static char *query(const struct sockaddr *address, char *buffer, socklen_t size);
 
     /**
      * Get the service port of a socket.
      * @param address of socket to examine.
      * @return service port number.
      */
-    static short getservice(struct sockaddr *address);
+    static short service(const struct sockaddr *address);
 
     /**
      * Get the service port of an inet socket.
      * @param address of internet socket to examine.
      * @return service port number.
      */
-    inline static short inetservice(struct sockaddr_internet *address)
-        {return getservice((struct sockaddr *)address);};
+    inline static short service(const struct sockaddr_internet *address)
+        {return service((const struct sockaddr *)address);};
 
     /**
      * Convert a socket address and service into a hash map index.
@@ -1513,7 +1483,7 @@ public:
      * @param size of map index.
      * @return key index path.
      */
-    static unsigned keyindex(struct sockaddr *address, unsigned size);
+    static unsigned keyindex(const struct sockaddr *address, unsigned size);
 
     /**
      * Convert a socket host address into a hash map index.
@@ -1521,7 +1491,7 @@ public:
      * @param size of map index.
      * @return key index path.
      */
-    static unsigned keyhost(struct sockaddr *address, unsigned size);
+    static unsigned keyhost(const struct sockaddr *address, unsigned size);
 
     /**
      * Initialize socket subsystem.
@@ -1537,9 +1507,9 @@ public:
     /**
      * Set default socket family preference for query options when the
      * socket type is otherwise not specified.
-     * @param query family to select.
+     * @param family to select.
      */
-    static void family(int query);
+    static void query(int family);
 
     /**
      * Set the default socket behavior for v6-v4 mapping.  This also
@@ -1563,7 +1533,7 @@ public:
      * @param string address to check.
      * @return true if zero/null address.
      */
-    static bool isNull(const char *string);
+    static bool is_null(const char *string);
 
     /**
      * Simple function to validate that a given IP address string is a numeric
@@ -1572,7 +1542,7 @@ public:
      * @param string address to check.
      * @return true if zero/null address.
      */
-    static bool isNumeric(const char *string);
+    static bool is_numeric(const char *string);
 
     /**
      * Get local address to which the socket is bound.  This is defined here
@@ -1582,7 +1552,7 @@ public:
      * @param address storage for local address.
      * @return 0 on success, -1 on failure.
      */
-    static int getlocal(socket_t socket, struct sockaddr_storage *address);
+    static int local(socket_t socket, struct sockaddr_storage *address);
 
     /**
      * Get remote address to which the socket is connected.  This is defined
@@ -1592,66 +1562,7 @@ public:
      * @param address storage for remote address.
      * @return 0 on success, -1 on failure.
      */
-    static int getremote(socket_t socket, struct sockaddr_storage *address);
-
-    /**
-     * Select without timeout.
-     * @param max socket id + 1.
-     * @param read mask of socket id's.
-     * @param write mask of socket id's.
-     * @param error mask of socket id's.
-     */
-    static int select(int max, set_t read, set_t write, set_t error);
-
-    /**
-     * Select with timeout.
-     * @param max socket id + 1.
-     * @param read mask of socket id's.
-     * @param write mask of socket id's.
-     * @param error mask of socket id's.
-     * @param timeout in milliseconds to wait for select activity.
-     */
-    static int select(int max, set_t read, set_t write, set_t error, timeout_t timeout);
-
-    /**
-     * Get a mask from the heap.
-     * @return mask to use, all bits cleared.
-     */
-    static set_t getmask(void);
-
-    /**
-     * Clear a mask, setting all entries to zero.
-     * @param mask to clear.
-     */
-    static void clear(set_t mask);
-
-    /**
-     * Release a heap allocated mask.
-     * @param mask to release.
-     */
-    static void release(set_t mask);
-
-    /**
-     * Set a socket entry in a mask.
-     * @param socket entry to set.
-     * @param mask to set entry in.
-     */
-    static void set(socket_t socket, set_t mask);
-
-    /**
-     * Clear a socket entry in a mask.
-     * @param socket entry to clear.
-     * @param mask to set entry in.
-     */
-    static void clear(socket_t socket, set_t mask);
-
-    /**
-     * Test a socket entry in a mask.
-     * @param socket entry to test.
-     * @param mask to set entry in.
-     * @return true if entry set.
-     */
-    static bool test(socket_t socket, set_t mask);
+    static int remote(socket_t socket, struct sockaddr_storage *address);
 };
 
 /**
@@ -1697,29 +1608,32 @@ public:
      * @param timeout to wait.
      * @return true when acceptable connection is pending.
      */
-    inline bool waitConnection(timeout_t timeout = Timer::inf) const
-        {return Socket::waitPending(timeout);};
+    inline bool wait(timeout_t timeout = Timer::inf) const
+        {return Socket::wait(timeout);};
 
     /**
      * Get the socket descriptor of the listener.
      * @return socket descriptor.
      */
     inline operator socket_t() const
-        {return so;};
+        {return so;}
 
     /**
      * Get the socket descriptor of the listener by pointer reference.
      * @return socket descriptor.
      */
     inline socket_t operator*() const
-        {return so;};
+        {return so;}
 
     /**
      * Get the socket descriptor of the listener.
      * @return socket descriptor.
      */
     inline socket_t getsocket(void) const
-        {return so;};
+        {return so;}
+
+    inline socket_t handle(void) const
+        {return so;}
 
 };
 
@@ -1865,17 +1779,12 @@ public:
         {ptr = _nextaddrinfo(ptr);};
 };
 
-/**
- * A convenience class for socket.
- */
-typedef Socket socket;
-
 /**
  * A convenience function to convert a socket address list into an addrinfo.
  * @param address list object.
  * @return addrinfo list or NULL if empty.
  */
-inline struct addrinfo *addrinfo(socket::address& address)
+inline struct addrinfo *addrinfo(Socket::address& address)
     {return address.getList();}
 
 /**
@@ -1884,8 +1793,8 @@ inline struct addrinfo *addrinfo(socket::address& address)
  * @param address list object.
  * @return first socket address in list or NULL if empty.
  */
-inline struct sockaddr *addr(socket::address& address)
-    {return address.getAddr();}
+inline struct sockaddr *addr(Socket::address& address)
+    {return address.get();}
 
 /**
  * Compare two socket addresses to see if equal.  If the port is zero
@@ -1894,7 +1803,7 @@ inline struct sockaddr *addr(socket::address& address)
  * @param s2 socket address to compare.
  * @return true if addresses same.
  */
-inline bool eq(struct sockaddr *s1, struct sockaddr *s2)
+inline bool eq(const struct sockaddr *s1, const struct sockaddr *s2)
     {return Socket::equal(s1, s2);}
 
 /**
@@ -1904,8 +1813,8 @@ inline bool eq(struct sockaddr *s1, struct sockaddr *s2)
  * @param s2 stored socket address to compare.
  * @return true if addresses same.
  */
-inline bool eq(struct sockaddr_storage *s1, struct sockaddr_storage *s2)
-    {return Socket::equal((struct sockaddr *)s1, (struct sockaddr *)s2);}
+inline bool eq(const struct sockaddr_storage *s1, const struct sockaddr_storage *s2)
+    {return Socket::equal((const struct sockaddr *)s1, (const struct sockaddr *)s2);}
 
 /**
  * Compare two host addresses to see if equal.  The port numbers are
@@ -1914,18 +1823,16 @@ inline bool eq(struct sockaddr_storage *s1, struct sockaddr_storage *s2)
  * @param s2 socket address to compare.
  * @return true if addresses same.
  */
-inline bool host_eq(struct sockaddr *s1, struct sockaddr *s2)
-    {return Socket::equalhost(s1, s2);}
+inline bool eq_host(const struct sockaddr *s1, const struct sockaddr *s2)
+    {return Socket::eq_host(s1, s2);}
 
-// to be depreciated...
-inline bool ieq(struct sockaddr *s1, struct sockaddr *s2)
-    {return Socket::equalhost(s1, s2);}
+inline bool eq_subnet(const struct sockaddr *s1, const struct sockaddr *s2)
+    {return Socket::eq_subnet(s1, s2);}
 
 String str(Socket& so, strsize_t size);
 
 typedef TCPServer   tcpserv_t;
 
-
 END_NAMESPACE
 
 #endif
