@@ -27,18 +27,15 @@ secure::~secure()
 {
 }
 
-bool secure::fips(const char *progname)
+bool secure::fips(void)
 {
     return false;
 }
 
-bool secure::init(const char *progname)
+bool secure::init(void)
 {
     Thread::init();
-    if(progname)
-        Socket::init(progname);
-    else
-        Socket::init();
+    Socket::init();
 
 #ifdef  _MSWINDOWS_
     if(_handle != (HCRYPTPROV)NULL)
@@ -57,17 +54,6 @@ bool secure::init(const char *progname)
     return false;
 }
 
-String secure::path(path_t id)
-{
-    switch(id) {
-    case SYSTEM_CERTIFICATES:
-        return str(SSL_CERTS);
-    case SYSTEM_KEYS:
-        return str(SSL_PRIVATE);
-    }
-    return str("");
-}
-
 #if defined(_MSWINDOWS_)
 
 static void cexport(HCERTSTORE ca, FILE *fp)
@@ -92,10 +78,26 @@ static void cexport(HCERTSTORE ca, FILE *fp)
     }
 }
 
+const char *secure::oscerts(void)
+{
+    const char *path = "c:/temp/ca-bundle.crt";
+    if(!is_file(path)) {
+        if(oscerts(path))
+            return NULL;
+    }
+    return path;
+}
+
 int secure::oscerts(const char *pathname)
 {
     bool caset;
-    string_t target = shell::path(shell::USER_CONFIG) + pathname;
+    string_t target;
+
+    if(pathname[1] == ':' || pathname[0] == '/' || pathname[0] == '\\')
+        target = pathname;
+    else
+        target = shell::path(shell::USER_CONFIG) + "/" + pathname;
+
     FILE *fp = fopen(*target, "wt");
 
     if(!fp)
@@ -118,18 +120,38 @@ int secure::oscerts(const char *pathname)
     fclose(fp);
 
     if(!caset) {
-        fsys::remove(*target);
+        fsys::erase(*target);
         return ENOSYS;
     }
     return 0;
 }
+
 #else
+const char *secure::oscerts(void)
+{
+    if(is_file("/etc/ssl/certs/ca-certificates.crt"))
+        return "/etc/ssl/certs/ca-certificates.crt";
+
+    if(is_file("/etc/pki/tls/ca-bundle.crt"))
+        return "/etc/pki/tls/ca-bundle.crt";
+
+    if(is_file("/etc/ssl/ca-bundle.pem"))
+        return "/etc/ssl/ca-bundle.pem";
+
+    return NULL;
+}
+
 int secure::oscerts(const char *pathname)
 {
-    string_t source = path(SYSTEM_CERTIFICATES) + "/ca-certificates.crt";
-    string_t target = shell::path(shell::USER_CONFIG) + pathname;
+    string_t source = oscerts();
+    string_t target;
 
-    if(!*source || !*target)
+    if(pathname[0] == '/')
+        target = pathname;
+    else
+        target = shell::path(shell::USER_CONFIG) + "/" + pathname;
+
+    if(!source)
         return ENOSYS;
 
     return fsys::copy(*source, *target);
